DeepChartTextLayout class

深度图文本布局结果。

默认实现用它描述底部价格标签所在区域和横向对齐方式。

Constructors

DeepChartTextLayout({required Rect rect, required TextAlign textAlign})
创建文本布局结果。
const

Properties

hashCode int
The hash code for this object.
no setterinherited
rect Rect
文本所在矩形区域。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlign TextAlign
文本在 rect 内的横向对齐方式。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited