DeepDepthNode class

深度图绘制节点。

节点在原始档位基础上补充了累计数量和绘制坐标,默认 delegate 使用它来绘制 累计深度面积图。

Annotations

Constructors

DeepDepthNode({required int index, required DeepDepthEntry entry, required double cumulativeSize, Offset? position})
创建深度图绘制节点。
const

Properties

cumulativeSize double
从第一个档位累计到当前档位的数量。
final
entry DeepDepthEntry
当前节点对应的原始盘口档位。
final
hashCode int
The hash code for this object.
no setterinherited
index int
当前节点在买盘或卖盘数组中的下标。
final
position Offset?
当前节点在画布坐标系中的位置。
final
price double
当前节点价格。
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
当前节点原始档位数量。
no setter

Methods

copyWith({Offset? position}) DeepDepthNode
复制节点并替换部分布局字段。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited