DeepChartContext<T> class
深度图布局、绘制和覆盖层构建时传递给 delegate 的上下文。
Constructors
-
DeepChartContext({required List<
T> bids, required List<T> asks, required DeepChartDataAdapter<T> adapter, required DeepChartTheme theme, required DeepChartLayoutConfig layout, required Size viewportSize, required DeepDepthNodes nodes}) -
创建深度图上下文。
const
Properties
-
adapter
→ DeepChartDataAdapter<
T> -
当前数据适配器。
final
-
asks
→ List<
T> -
卖盘原始数据。
final
-
bids
→ List<
T> -
买盘原始数据。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → DeepChartLayoutConfig
-
当前布局配置。
final
- nodes → DeepDepthNodes
-
已完成累计数量和坐标计算的节点集合。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → DeepChartTheme
-
当前主题配置。
final
- viewportSize → Size
-
当前组件视口尺寸。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited